# Callable Folder 0.3.0
# (c) 2000-2001, Stefan H. Holek, stefan@epy.co.at
# http://www.zope.org/Members/shh/
# License: ZPL
# Zope: 2.3

__doc__ = 'A Callable Folder has its __call__() method overridden to invoke a contained index_html method'
__version__ = '0.3.0'

from OFS.Folder import Folder
from Globals import HTMLFile, default__class_init__
from AccessControl import getSecurityManager


class CallableFolder( Folder ):
  '''Simply be a Folder with a __call__() method 
  '''
  meta_type = 'Callable Folder'
  icon = 'misc_/CallableFolder/CallableFolder_icon.gif'

  isDocTemp = 1         # Pretend to be a doc template

  def __call__( self, client=None, REQUEST={}, RESPONSE=None, **kw ):
    '''Call index_html, if it exists
    '''
    local = getattr( self, 'aq_base', self )
    if hasattr( local, 'index_html' ):
      method = local.index_html
      args = (self, REQUEST, RESPONSE)     
      return apply( method, args, kw )
    else:
      raise AttributeError, 'index_html'


  manage_addCallableFolderForm = HTMLFile( 'dtml/callablefolderAdd', globals() )


  def manage_addCallableFolder( self, id, title='', createPublic=0, createUserF=0, REQUEST=None ):
    '''Add a CallableFolder instance
    '''
    ob = CallableFolder()
    ob.id = str( id )
    ob.title = title
    self._setObject( id, ob )
    ob = self._getOb( id )

    checkPermission = getSecurityManager().checkPermission

    if createUserF:
      if not checkPermission( 'Add User Folders', ob ):
        raise 'Unauthorized', ('You are not authorized to add User Folders.')
      ob.manage_addUserFolder()

    if createPublic:
      if not checkPermission( 'Add Documents, Images, and Files', ob ):
        raise 'Unauthorized', ('You are not authorized to add DTML Methods.')
      ob.manage_addDTMLMethod( id='index_html', title='' )

    if REQUEST is not None:
      return self.manage_main( self, REQUEST, update_menu=1 )


default__class_init__( CallableFolder )

